Task: LIGHT-Dialogue-Wild
=========================
Description: LIGHT is a text adventure game with actions and dialogue. 
The WILD dataset here features 41,131 training episodes of dialogue from [deploying as a game](https://arxiv.org/abs/1911.03842).

Link: http://parl.ai/projects/light

Tags: #LIGHT-Dialogue, #All, #Grounded

